==> apache-streampark-2.0.0-incubating-src.tar.gz: apache-streampark-2.0.0-incubating-src/streampark-flink/streampark-flink-connector/streampark-flink-connector-doris/src/main/java/org/apache/streampark/flink/connector/doris/bean/LoadStatusFailedException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.streampark.flink.connector.doris.bean;

import java.io.IOException;
import java.util.Map;

public class LoadStatusFailedException extends IOException {

  static final long serialVersionUID = 1L;
  private final Map<String, Object> response;
  private boolean reCreateLabel;

  public LoadStatusFailedException(String message, Map<String, Object> response) {
    super(message);
    this.response = response;
  }

  public LoadStatusFailedException(
      String message, Map<String, Object> response, boolean reCreateLabel) {
    super(message);
    this.response = response;
    this.reCreateLabel = reCreateLabel;
  }

  public Map<String, Object> getFailedResponse() {
    return response;
  }

  public boolean needReCreateLabel() {
    return reCreateLabel;
  }
}

==> apache-streampark-2.1.3-incubating-src.tar.gz: apache-streampark-2.1.3-incubating-src/streampark-flink/streampark-flink-connector/streampark-flink-connector-doris/src/main/java/org/apache/streampark/flink/connector/doris/bean/LoadStatusFailedException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.streampark.flink.connector.doris.bean;

import java.io.IOException;
import java.util.Map;

public class LoadStatusFailedException extends IOException {

  private static final long serialVersionUID = 1L;
  private final Map<String, Object> response;
  private boolean reCreateLabel;

  public LoadStatusFailedException(String message, Map<String, Object> response) {
    super(message);
    this.response = response;
  }

  public LoadStatusFailedException(
      String message, Map<String, Object> response, boolean reCreateLabel) {
    super(message);
    this.response = response;
    this.reCreateLabel = reCreateLabel;
  }

  public Map<String, Object> getFailedResponse() {
    return response;
  }

  public boolean needReCreateLabel() {
    return reCreateLabel;
  }
}
